@@ -4,6 +4,8 @@ from abc import abstractmethod
 from pydantic import BaseModel
 from typing import Callable, Iterator, get_type_hints, Union, Any, Optional
 
+from .query import get_filtration
+
 
 class FieldsView:
     def __init__(self, items: set[str]) -> None:
@@ -50,4 +52,4 @@ class Filterable:
 
     @classmethod
     def filter(cls) -> Callable:
-        raise NotImplementedError
+        return get_filtration(cls.fields())
